Here you find the code reference for the two main components users of `PyStemmusScope`
might need. First is the StemmusScope model class. Second is the `save` module, with
which you can save the STEMMUS_SCOPE model output to a netCDF file.

## **PyStemmusScope**:

::: PyStemmusScope.stemmus_scope.StemmusScope
    options:
      show_root_heading: false
      show_source: true
      heading_level: 3


## **PyStemmusScope.save**:

::: PyStemmusScope.save
    options:
      show_root_heading: true
      show_source: true
      heading_level: 3
